@@ -16,7 +16,13 @@
 
 package com.igormaznitsa.jbbp.compiler.varlen;
 
-import com.igormaznitsa.jbbp.JBBPExternalValueProvider;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
+
 import com.igormaznitsa.jbbp.JBBPNamedNumericFieldMap;
 import com.igormaznitsa.jbbp.compiler.JBBPCompiledBlock;
 import com.igormaznitsa.jbbp.compiler.JBBPCompiler;
@@ -26,41 +32,42 @@ import com.igormaznitsa.jbbp.exceptions.JBBPEvalException;
 import com.igormaznitsa.jbbp.io.JBBPBitInputStream;
 import com.igormaznitsa.jbbp.model.JBBPFieldInt;
 import com.igormaznitsa.jbbp.utils.JBBPUtils;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.function.Executable;
-
 import java.io.ByteArrayInputStream;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-
-import static org.junit.jupiter.api.Assertions.*;
+import org.junit.jupiter.api.Test;
 
 public class JBBPExpressionEvaluatorTest {
 
   @Test
   public void testExpression_Error_ConstantsWithoutOperators() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator(" 1   334", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator(" 1   334", null, null));
   }
 
   @Test
   public void testExpression_Error_OnlyBrackets() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator(" ( ( ( ( ) )) )  ", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator(" ( ( ( ( ) )) )  ", null, null));
   }
 
   @Test
   public void testExpression_Error_NonClosedBracket() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("(34+45  ", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("(34+45  ", null, null));
   }
 
   @Test
   public void testExpression_Error_NonOpenedBracket() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("34+45)  ", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("34+45)  ", null, null));
   }
 
   @Test
   public void testExpression_Error_Spaces() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("  ", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("  ", null, null));
   }
 
   @Test
@@ -70,72 +77,86 @@ public class JBBPExpressionEvaluatorTest {
 
   @Test
   public void testExpression_Error_OnlyUnaryPlus() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("+", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("+", null, null));
   }
 
   @Test
   public void testExpression_Error_OnlyUnaryMinus() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("-", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("-", null, null));
   }
 
   @Test
   public void testExpression_Error_OnlyNot() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("~", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("~", null, null));
   }
 
   @Test
   public void testExpression_Error_WrongFirstUnaryOperator() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("%345", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("%345", null, null));
   }
 
   @Test
   public void testExpression_Error_WrongUnaryOperator() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("222%%345", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("222%%345", null, null));
   }
 
   @Test
   public void testExpression_Error_OnlyNonUnaryOperator() {
-    assertThrows(JBBPCompilationException.class, () -> new JBBPExpressionEvaluator("*", null, null));
+    assertThrows(JBBPCompilationException.class,
+        () -> new JBBPExpressionEvaluator("*", null, null));
   }
 
   @Test
   public void testExpression_Error_MulWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123*", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123*", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_SubWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123-", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123-", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_AddWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123+", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123+", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_ModWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123%", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123%", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_DivWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123/", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123/", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_AndWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123&", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123&", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_OrWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123|", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123|", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_Error_XorWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("123^", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("123^", null, null).eval(null, 0, null, null));
   }
 
   @Test
@@ -163,7 +184,9 @@ public class JBBPExpressionEvaluatorTest {
     JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("hello", list, compiled);
     final JBBPNamedNumericFieldMap map = new JBBPNamedNumericFieldMap();
     map.putField(new JBBPFieldInt(info, 1234));
-    assertEquals(1234, expr.eval(null, 0, JBBPCompiledBlock.prepare().setCompiledData(compiled).setNamedFieldData(list).setSource("no source").build(), map));
+    assertEquals(1234, expr.eval(null, 0,
+        JBBPCompiledBlock.prepare().setCompiledData(compiled).setNamedFieldData(list)
+            .setSource("no source").build(), map));
   }
 
   @Test
@@ -172,17 +195,24 @@ public class JBBPExpressionEvaluatorTest {
     final byte[] compiled = new byte[] {JBBPCompiler.CODE_INT | JBBPCompiler.FLAG_NAMED};
     final List<JBBPNamedFieldInfo> list = Collections.singletonList(info);
 
-    JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("2*hello*6/4+3*2-11%3&hello-~hello", list, compiled);
+    JBBPExpressionEvaluator expr =
+        new JBBPExpressionEvaluator("2*hello*6/4+3*2-11%3&hello-~hello", list, compiled);
     final JBBPNamedNumericFieldMap map = new JBBPNamedNumericFieldMap();
     map.putField(new JBBPFieldInt(info, 8));
-    assertEquals(2 * 8 * 6 / 4 + 3 * 2 - 11 % 3 & 8 - ~8, expr.eval(null, 0, JBBPCompiledBlock.prepare().setCompiledData(compiled).setNamedFieldData(list).setSource("no source").build(), map));
+    assertEquals(2 * 8 * 6 / 4 + 3 * 2 - 11 % 3 & 8 - ~8, expr.eval(null, 0,
+        JBBPCompiledBlock.prepare().setCompiledData(compiled).setNamedFieldData(list)
+            .setSource("no source").build(), map));
   }
 
   @Test
   public void testExpression_MustNotThrowStackOverfow() throws Exception {
-    JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("1+(2+(3+(4+(5+(6+(7+(8+(9+(10+(11+(12+(13+(14+(15+(16+(17+(18+(19+(20*2)))))))))))))))))))", null, null);
+    JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator(
+        "1+(2+(3+(4+(5+(6+(7+(8+(9+(10+(11+(12+(13+(14+(15+(16+(17+(18+(19+(20*2)))))))))))))))))))",
+        null, null);
     assertEquals(21, expr.getMaxStackDepth());
-    assertEquals(1 + (2 + (3 + (4 + (5 + (6 + (7 + (8 + (9 + (10 + (11 + (12 + (13 + (14 + (15 + (16 + (17 + (18 + (19 + (20 * 2))))))))))))))))))), expr.eval(null, 0, null, null));
+    assertEquals(1 + (2 + (3 + (4 + (5 + (6 + (7 + (8 +
+            (9 + (10 + (11 + (12 + (13 + (14 + (15 + (16 + (17 + (18 + (19 + (20 * 2))))))))))))))))))),
+        expr.eval(null, 0, null, null));
   }
 
   @Test
@@ -271,7 +301,9 @@ public class JBBPExpressionEvaluatorTest {
     assertEquals(2, expr.getMaxStackDepth());
     final JBBPNamedNumericFieldMap map = new JBBPNamedNumericFieldMap();
     map.putField(new JBBPFieldInt(varA, 123));
-    assertEquals(123 * 2, expr.eval(null, 0, JBBPCompiledBlock.prepare().setCompiledData(compiled).setNamedFieldData(list).setSource("no source").build(), map));
+    assertEquals(123 * 2, expr.eval(null, 0,
+        JBBPCompiledBlock.prepare().setCompiledData(compiled).setNamedFieldData(list)
+            .setSource("no source").build(), map));
   }
 
   @Test
@@ -402,9 +434,11 @@ public class JBBPExpressionEvaluatorTest {
 
   @Test
   public void testExpression_ComplexLogicalWithConstants() {
-    JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("~23*-1234&~123/(34+89)|3232%56^~2234", null, null);
+    JBBPExpressionEvaluator expr =
+        new JBBPExpressionEvaluator("~23*-1234&~123/(34+89)|3232%56^~2234", null, null);
     assertEquals(4, expr.getMaxStackDepth());
-    assertEquals((~23 * -1234 & ~123 / (34 + 89)) | (3232 % 56 ^ ~2234), expr.eval(null, 0, null, null));
+    assertEquals((~23 * -1234 & ~123 / (34 + 89)) | (3232 % 56 ^ ~2234),
+        expr.eval(null, 0, null, null));
   }
 
   @Test
@@ -416,7 +450,8 @@ public class JBBPExpressionEvaluatorTest {
 
   @Test
   public void testExpression_LeftShift_ErrorWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("1234<<", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("1234<<", null, null).eval(null, 0, null, null));
   }
 
   @Test
@@ -428,7 +463,8 @@ public class JBBPExpressionEvaluatorTest {
 
   @Test
   public void testExpression_RightShift_ErrorWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("1234 >>", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("1234 >>", null, null).eval(null, 0, null, null));
   }
 
   @Test
@@ -447,40 +483,47 @@ public class JBBPExpressionEvaluatorTest {
 
   @Test
   public void testExpression_RightSignShift_ErrorWithoutSecondArgument() {
-    assertThrows(JBBPEvalException.class, () -> new JBBPExpressionEvaluator("1234 >>>", null, null).eval(null, 0, null, null));
+    assertThrows(JBBPEvalException.class,
+        () -> new JBBPExpressionEvaluator("1234 >>>", null, null).eval(null, 0, null, null));
   }
 
   @Test
   public void testExpression_ReverseByte() {
-    JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("((($v*2050&139536)|($v*32800&558144))*65793>>16)&255", null, null);
+    JBBPExpressionEvaluator expr =
+        new JBBPExpressionEvaluator("((($v*2050&139536)|($v*32800&558144))*65793>>16)&255", null,
+            null);
     assertEquals(3, expr.getMaxStackDepth());
-    assertEquals(JBBPUtils.reverseBitsInByte((byte) 123) & 0xFF, expr.eval(null, 0, null, new JBBPNamedNumericFieldMap((fieldName, numericFieldMap, compiledBlock) -> {
-      if ("v".equals(fieldName)) {
-        return 123;
-      } else {
-        fail("Unexpected field [" + fieldName + ']');
-        return 0;
-      }
-    })));
+    assertEquals(JBBPUtils.reverseBitsInByte((byte) 123) & 0xFF, expr.eval(null, 0, null,
+        new JBBPNamedNumericFieldMap((fieldName, numericFieldMap, compiledBlock) -> {
+          if ("v".equals(fieldName)) {
+            return 123;
+          } else {
+            fail("Unexpected field [" + fieldName + ']');
+            return 0;
+          }
+        })));
   }
 
   @Test
   public void testExpression_CheckExternalField() {
     final int value = 1234;
-    final JBBPNamedNumericFieldMap map = new JBBPNamedNumericFieldMap((fieldName, numericFieldMap, compiledBlock) -> {
-      if (fieldName.equals("value")) {
-        return value;
-      }
-      assertNotNull(numericFieldMap);
-      assertNotNull(compiledBlock);
-      fail("Unexpected request for value [" + fieldName + ']');
-      return -1;
-    });
+    final JBBPNamedNumericFieldMap map =
+        new JBBPNamedNumericFieldMap((fieldName, numericFieldMap, compiledBlock) -> {
+          if (fieldName.equals("value")) {
+            return value;
+          }
+          assertNotNull(numericFieldMap);
+          assertNotNull(compiledBlock);
+          fail("Unexpected request for value [" + fieldName + ']');
+          return -1;
+        });
 
     final List<JBBPNamedFieldInfo> list = new ArrayList<>();
 
     final byte[] compiled = new byte[] {0};
-    final JBBPCompiledBlock compiledBlock = JBBPCompiledBlock.prepare().setCompiledData(compiled).setSource("none").setNamedFieldData(list).build();
+    final JBBPCompiledBlock compiledBlock =
+        JBBPCompiledBlock.prepare().setCompiledData(compiled).setSource("none")
+            .setNamedFieldData(list).build();
 
     JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("123*($value-45/3)", list, compiled);
     assertEquals(4, expr.getMaxStackDepth());
@@ -496,25 +539,30 @@ public class JBBPExpressionEvaluatorTest {
   @Test
   public void testExpression_CheckExternalFieldAndStreamOffset() throws Exception {
     final int value = 1234;
-    final JBBPNamedNumericFieldMap map = new JBBPNamedNumericFieldMap((fieldName, numericFieldMap, compiledBlock) -> {
-      if (fieldName.equals("value")) {
-        return value;
-      }
-      assertNotNull(numericFieldMap);
-      assertNotNull(compiledBlock);
-      fail("Unexpected request for value [" + fieldName + ']');
-      return -1;
-    });
+    final JBBPNamedNumericFieldMap map =
+        new JBBPNamedNumericFieldMap((fieldName, numericFieldMap, compiledBlock) -> {
+          if (fieldName.equals("value")) {
+            return value;
+          }
+          assertNotNull(numericFieldMap);
+          assertNotNull(compiledBlock);
+          fail("Unexpected request for value [" + fieldName + ']');
+          return -1;
+        });
 
     final List<JBBPNamedFieldInfo> list = new ArrayList<>();
 
     final byte[] compiled = new byte[] {0};
-    final JBBPCompiledBlock compiledBlock = JBBPCompiledBlock.prepare().setCompiledData(compiled).setSource("none").setNamedFieldData(list).build();
+    final JBBPCompiledBlock compiledBlock =
+        JBBPCompiledBlock.prepare().setCompiledData(compiled).setSource("none")
+            .setNamedFieldData(list).build();
 
-    JBBPExpressionEvaluator expr = new JBBPExpressionEvaluator("123*($value-45/3)*$$", list, compiled);
+    JBBPExpressionEvaluator expr =
+        new JBBPExpressionEvaluator("123*($value-45/3)*$$", list, compiled);
     assertEquals(4, expr.getMaxStackDepth());
 
-    final JBBPBitInputStream inStream = new JBBPBitInputStream(new ByteArrayInputStream(new byte[] {1, 2, 3, 4, 5}));
+    final JBBPBitInputStream inStream =
+        new JBBPBitInputStream(new ByteArrayInputStream(new byte[] {1, 2, 3, 4, 5}));
     inStream.read();
     inStream.read();
     inStream.read();
